package jdk.javadoc.internal.doclets.formats.html.resources;

public final class standard extends java.util.ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "doclet.All_Modules", "All Modules" },
            { "doclet.All_Packages", "All Packages" },
            { "doclet.Annotation_Interface_Hierarchy", "Annotation Interface Hierarchy" },
            { "doclet.Annotation_Interface_Members", "Annotation Interface Elements" },
            { "doclet.Annotation_Interfaces", "Annotation Interfaces" },
            { "doclet.Annotation_Type_Hierarchy", "Annotation Type Hierarchy" },
            { "doclet.Annotation_Type_Members", "Annotation Type Elements" },
            { "doclet.Annotation_Types", "Annotation Types" },
            { "doclet.ClassUse_Annotation", "Classes in {1} with annotations of type {0}" },
            { "doclet.ClassUse_Classes.in.0.used.by.1", "Classes in {0} used by {1}" },
            { "doclet.ClassUse_ConstructorAnnotations", "Constructors in {1} with annotations of type {0}" },
            { "doclet.ClassUse_ConstructorArgs", "Constructors in {1} with parameters of type {0}" },
            { "doclet.ClassUse_ConstructorArgsTypeParameters", "Constructor parameters in {1} with type arguments of type {0}" },
            { "doclet.ClassUse_ConstructorParameterAnnotations", "Constructor parameters in {1} with annotations of type {0}" },
            { "doclet.ClassUse_ConstructorThrows", "Constructors in {1} that throw {0}" },
            { "doclet.ClassUse_Field", "Fields in {1} declared as {0}" },
            { "doclet.ClassUse_FieldAnnotations", "Fields in {1} with annotations of type {0}" },
            { "doclet.ClassUse_FieldTypeParameter", "Fields in {1} with type parameters of type {0}" },
            { "doclet.ClassUse_ImplementingClass", "Classes in {1} that implement {0}" },
            { "doclet.ClassUse_MethodAnnotations", "Methods in {1} with annotations of type {0}" },
            { "doclet.ClassUse_MethodArgs", "Methods in {1} with parameters of type {0}" },
            { "doclet.ClassUse_MethodArgsTypeParameters", "Method parameters in {1} with type arguments of type {0}" },
            { "doclet.ClassUse_MethodParameterAnnotations", "Method parameters in {1} with annotations of type {0}" },
            { "doclet.ClassUse_MethodReturn", "Methods in {1} that return {0}" },
            { "doclet.ClassUse_MethodReturnTypeParameter", "Methods in {1} that return types with arguments of type {0}" },
            { "doclet.ClassUse_MethodThrows", "Methods in {1} that throw {0}" },
            { "doclet.ClassUse_MethodTypeParameter", "Methods in {1} with type parameters of type {0}" },
            { "doclet.ClassUse_No.usage.of.0", "No usage of {0}" },
            { "doclet.ClassUse_PackageAnnotation", "Packages with annotations of type {0}" },
            { "doclet.ClassUse_Packages.that.use.0", "Packages that use {0}" },
            { "doclet.ClassUse_Subclass", "Subclasses of {0} in {1}" },
            { "doclet.ClassUse_Subinterface", "Subinterfaces of {0} in {1}" },
            { "doclet.ClassUse_Title", "Uses of {0}" },
            { "doclet.ClassUse_TypeParameter", "Classes in {1} with type parameters of type {0}" },
            { "doclet.ClassUse_Uses.of.0.in.1", "Uses of {0} in {1}" },
            { "doclet.Class_Hierarchy", "Class Hierarchy" },
            { "doclet.Constructor_for", "Constructor for {0}" },
            { "doclet.Contents", "Contents" },
            { "doclet.Deprecated_API", "Deprecated API" },
            { "doclet.Description", "Description" },
            { "doclet.Description_From_Class", "Description copied from class:" },
            { "doclet.Description_From_Interface", "Description copied from interface:" },
            { "doclet.Detail", "Detail:" },
            { "doclet.Element", "Element" },
            { "doclet.Element_in", "Element in {0}" },
            { "doclet.Enclosing_Class", "Enclosing class:" },
            { "doclet.Enclosing_Interface", "Enclosing interface:" },
            { "doclet.Enum_Class_Hierarchy", "Enum Class Hierarchy" },
            { "doclet.Enum_Hierarchy", "Enum Hierarchy" },
            { "doclet.Enum_constant_in", "Enum constant in {0}" },
            { "doclet.Error_in_grouplist", "Bad -group option: {0} {1}" },
            { "doclet.File_error", "Error reading file: {0}" },
            { "doclet.For_Removal", "For Removal" },
            { "doclet.Functional_Interface", "Functional Interface:" },
            { "doclet.Functional_Interface_Message", "This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference." },
            { "doclet.Generated_Docs_Untitled", "Generated Documentation (Untitled)" },
            { "doclet.Groupname_already_used", "In -group option, group name already used: {0}" },
            { "doclet.Help", "Help" },
            { "doclet.Hierarchy_For_All_Packages", "Hierarchy For All Packages" },
            { "doclet.Hierarchy_For_Package", "Hierarchy For Package {0}" },
            { "doclet.Href_Annotation_Title", "annotation in {0}" },
            { "doclet.Href_Class_Or_Interface_Title", "class or interface in {0}" },
            { "doclet.Href_Class_Title", "class in {0}" },
            { "doclet.Href_Enum_Class_Title", "enum class in {0}" },
            { "doclet.Href_Enum_Title", "enum in {0}" },
            { "doclet.Href_Interface_Title", "interface in {0}" },
            { "doclet.Href_Type_Param_Title", "type parameter in {0}" },
            { "doclet.Implementing_Classes", "All Known Implementing Classes:" },
            { "doclet.Index", "Index" },
            { "doclet.Inheritance_Tree", "Inheritance Tree" },
            { "doclet.Interface_Hierarchy", "Interface Hierarchy" },
            { "doclet.Interfaces", "Interfaces" },
            { "doclet.MalformedURL", "Malformed URL: {0}" },
            { "doclet.Method_in", "Method in {0}" },
            { "doclet.Module", "Module" },
            { "doclet.Module_Sub_Nav", "Module:" },
            { "doclet.Navigation", "Navigation" },
            { "doclet.New_Page", "NewPage" },
            { "doclet.NoFrames_specified", "The --no-frames option is no longer required and may be removed\nin a future release." },
            { "doclet.No_Non_Deprecated_Classes_To_Document", "No non-deprecated classes found to document." },
            { "doclet.No_Script_Message", "JavaScript is disabled on your browser." },
            { "doclet.None", "None" },
            { "doclet.Open_Module", "Open Module" },
            { "doclet.Other_Packages", "Other Packages" },
            { "doclet.Overrides", "Overrides:" },
            { "doclet.Overview", "Overview" },
            { "doclet.Package", "Package" },
            { "doclet.Package_Hierarchies", "Package Hierarchies:" },
            { "doclet.Record_component_in", "Record component of {0}" },
            { "doclet.ReferencedIn", "Referenced In" },
            { "doclet.Resource_error", "Error reading resource: {0}" },
            { "doclet.Same_element_name_used", "Element name or pattern used twice: {0}" },
            { "doclet.Search_tag_in", "Search tag in {0}" },
            { "doclet.Skip_navigation_links", "Skip navigation links" },
            { "doclet.Specified_By", "Specified by:" },
            { "doclet.Static_method_in", "Static method in {0}" },
            { "doclet.Static_variable_in", "Static variable in {0}" },
            { "doclet.Subclasses", "Direct Known Subclasses:" },
            { "doclet.Subinterfaces", "All Known Subinterfaces:" },
            { "doclet.Summary", "Summary:" },
            { "doclet.System_Property", "System Property" },
            { "doclet.Tree", "Tree" },
            { "doclet.URL_error", "Error fetching URL: {0}" },
            { "doclet.Variable_in", "Variable in {0}" },
            { "doclet.Window_ClassUse_Header", "Uses of {0} {1}" },
            { "doclet.Window_Class_Hierarchy", "Class Hierarchy" },
            { "doclet.Window_Deprecated_List", "Deprecated List" },
            { "doclet.Window_Help_title", "API Help" },
            { "doclet.Window_Overview_Summary", "Overview" },
            { "doclet.Window_Single_Index", "Index" },
            { "doclet.Window_Source_title", "Source code" },
            { "doclet.Window_Split_Index", "{0}-Index" },
            { "doclet.also", "also" },
            { "doclet.annotation_interface_members", "annotation interface elements" },
            { "doclet.annotation_interfaces", "annotation interfaces" },
            { "doclet.annotation_type_members", "annotation type elements" },
            { "doclet.annotation_types", "annotation types" },
            { "doclet.build_version", "Standard Doclet version {0}" },
            { "doclet.footer_specified", "The -footer option is no longer supported and will be ignored.\nIt may be removed in a future release." },
            { "doclet.for_removal", "for removal" },
            { "doclet.help.annotation_interface.declaration", "Annotation Interface Declaration" },
            { "doclet.help.annotation_interface.description", "Annotation Interface Description" },
            { "doclet.help.annotation_interface.intro", "Each annotation interface has its own separate page with the following sections:" },
            { "doclet.help.annotation_type.declaration", "Annotation Type Declaration" },
            { "doclet.help.annotation_type.description", "Annotation Type Description" },
            { "doclet.help.annotation_type.intro", "Each annotation type has its own separate page with the following sections:" },
            { "doclet.help.class_interface.declaration", "Class or Interface Declaration" },
            { "doclet.help.class_interface.description", "Class or Interface Description" },
            { "doclet.help.class_interface.head", "Class or Interface" },
            { "doclet.help.class_interface.implementations", "All Known Implementing Classes" },
            { "doclet.help.class_interface.inheritance_diagram", "Class Inheritance Diagram" },
            { "doclet.help.class_interface.intro", "Each class, interface, nested class and nested interface has its own separate page. Each of these pages has three sections consisting of a class/interface description, summary tables, and detailed member descriptions:" },
            { "doclet.help.class_interface.subclasses", "Direct Subclasses" },
            { "doclet.help.class_interface.subinterfaces", "All Known Subinterfaces" },
            { "doclet.help.class_interface.summary", "The summary entries are alphabetical, while the detailed descriptions are in the order they appear in the source code. This preserves the logical groupings established by the programmer." },
            { "doclet.help.constants.body", "The {0} page lists the static final fields and their values." },
            { "doclet.help.deprecated.body", "The {0} page lists all of the API that have been deprecated. A deprecated API is not recommended for use, generally due to shortcomings, and a replacement API is usually given. Deprecated APIs may be removed in future implementations." },
            { "doclet.help.enum.class.intro", "Each enum class has its own separate page with the following sections:" },
            { "doclet.help.enum.declaration", "Enum Declaration" },
            { "doclet.help.enum.definition", "Enum Description" },
            { "doclet.help.enum.intro", "Each enum has its own separate page with the following sections:" },
            { "doclet.help.footnote", "This help file applies to API documentation generated by the standard doclet." },
            { "doclet.help.index.body", "The {0} contains an alphabetic index of all classes, interfaces, constructors, methods, and fields, as well as lists of all packages and all classes." },
            { "doclet.help.index.head", "Index" },
            { "doclet.help.intro", "This API (Application Programming Interface) document has pages corresponding to the items in the navigation bar, described as follows." },
            { "doclet.help.main_heading", "How This API Document Is Organized" },
            { "doclet.help.module.intro", "Each module has a page that contains a list of its packages, dependencies on other modules, and services, with a summary for each. These pages may contain three categories:" },
            { "doclet.help.overview.modules.body", "The {0} page is the front page of this API document and provides a list of all modules with a summary for each.  This page can also contain an overall description of the set of modules." },
            { "doclet.help.overview.packages.body", "The {0} page is the front page of this API document and provides a list of all packages with a summary for each.  This page can also contain an overall description of the set of packages." },
            { "doclet.help.package.intro", "Each package has a page that contains a list of its classes and interfaces, with a summary for each. These pages may contain six categories:" },
            { "doclet.help.search.example", "{0} will match {1}" },
            { "doclet.help.search.head", "Search" },
            { "doclet.help.search.intro", "You can search for definitions of modules, packages, types, fields, methods, system properties and other terms defined in the API, using some or all of the name, optionally using \"camel-case\" abbreviations. For example:" },
            { "doclet.help.search.refer", "Refer to {0} for a full description of search features." },
            { "doclet.help.search.spec.title", "the Javadoc Search Specification" },
            { "doclet.help.search.spec.url", "https://docs.oracle.com/en/java/javase/{0}/docs/specs/javadoc/javadoc-search-spec.html" },
            { "doclet.help.serial_form.body", "Each serializable or externalizable class has a description of its serialization fields and methods. This information is of interest to those who implement rather than use the API. While there is no link in the navigation bar, you can get to this information by going to any serialized class and clicking \"Serialized Form\" in the \"See Also\" section of the class description." },
            { "doclet.help.systemProperties.body", "The {0} page lists references to system properties." },
            { "doclet.help.tree.head", "Tree (Class Hierarchy)" },
            { "doclet.help.tree.intro", "There is a {0} page for all packages, plus a hierarchy for each package. Each hierarchy page contains a list of classes and a list of interfaces. Classes are organized by inheritance structure starting with {1}. Interfaces do not inherit from {1}." },
            { "doclet.help.tree.overview", "When viewing the Overview page, clicking on \"Tree\" displays the hierarchy for all packages." },
            { "doclet.help.tree.package", "When viewing a particular package, class or interface page, clicking on \"Tree\" displays the hierarchy for only that package." },
            { "doclet.help.use.body", "Each documented package, class and interface has its own Use page.  This page describes what packages, classes, methods, constructors and fields use any part of the given class or package. Given a class or interface A, its \"Use\" page includes subclasses of A, fields declared as A, methods that return A, and methods and constructors with parameters of type A.  You can access this page by first going to the package, class or interface, then clicking on the \"Use\" link in the navigation bar." },
            { "doclet.help.use.head", "Use" },
            { "doclet.in_class", "in class" },
            { "doclet.in_interface", "in interface" },
            { "doclet.module", "module" },
            { "doclet.navAnnotationTypeMember", "Element" },
            { "doclet.navAnnotationTypeOptionalMember", "Optional" },
            { "doclet.navAnnotationTypeRequiredMember", "Required" },
            { "doclet.navClassUse", "Use" },
            { "doclet.navConstructor", "Constr" },
            { "doclet.navDeprecated", "Deprecated" },
            { "doclet.navEnum", "Enum Constants" },
            { "doclet.navField", "Field" },
            { "doclet.navMethod", "Method" },
            { "doclet.navModuleDescription", "Description" },
            { "doclet.navModules", "Modules" },
            { "doclet.navNested", "Nested" },
            { "doclet.navPackages", "Packages" },
            { "doclet.navProperty", "Property" },
            { "doclet.navServices", "Services" },
            { "doclet.not.exhaustive", "(not exhaustive)" },
            { "doclet.package", "package" },
            { "doclet.record_classes", "record classes" },
            { "doclet.see.class_or_package_not_accessible", "Tag {0}: reference not accessible: {1}" },
            { "doclet.see.class_or_package_not_found", "Tag {0}: reference not found: {1}" },
            { "doclet.systemProperties", "System Properties" },
            { "doclet.systemPropertiesSummary", "System Properties Summary" },
            { "doclet.tag.invalid_usage", "invalid usage of tag {0}" },
            { "doclet.usage.add-stylesheet.description", "Additional stylesheet file for the generated documentation" },
            { "doclet.usage.add-stylesheet.parameters", "<file>" },
            { "doclet.usage.allow-script-in-comments.description", "Allow JavaScript in options and comments" },
            { "doclet.usage.author.description", "Include @author paragraphs" },
            { "doclet.usage.bottom.description", "Include bottom text for each page" },
            { "doclet.usage.bottom.parameters", "<html-code>" },
            { "doclet.usage.charset.description", "Charset for cross-platform viewing of generated documentation" },
            { "doclet.usage.charset.parameters", "<charset>" },
            { "doclet.usage.d.description", "Destination directory for output files" },
            { "doclet.usage.d.parameters", "<directory>" },
            { "doclet.usage.docencoding.description", "Specify the character encoding for the output" },
            { "doclet.usage.docencoding.parameters", "<name>" },
            { "doclet.usage.docfilessubdirs.description", "Recursively copy doc-file subdirectories" },
            { "doclet.usage.doctitle.description", "Include title for the overview page" },
            { "doclet.usage.doctitle.parameters", "<html-code>" },
            { "doclet.usage.excludedocfilessubdir.description", "Exclude any doc-files subdirectories with given name" },
            { "doclet.usage.excludedocfilessubdir.parameters", "<name>:..." },
            { "doclet.usage.footer.description", "Include footer text for each page" },
            { "doclet.usage.footer.parameters", "<html-code>" },
            { "doclet.usage.frames.description", "Enable the use of frames in the generated output" },
            { "doclet.usage.group.description", "Group specified elements together in overview page" },
            { "doclet.usage.group.parameters", "<name> <g1>:<g2>..." },
            { "doclet.usage.header.description", "Include header text for each page" },
            { "doclet.usage.header.parameters", "<html-code>" },
            { "doclet.usage.helpfile.description", "Include file that help link links to" },
            { "doclet.usage.helpfile.parameters", "<file>" },
            { "doclet.usage.html5.description", "Generate HTML 5 output. This option is no longer required." },
            { "doclet.usage.javafx.description", "Enable JavaFX functionality" },
            { "doclet.usage.keywords.description", "Include HTML meta tags with package, class and member info" },
            { "doclet.usage.link-platform-properties.description", "Link to platform documentation URLs declared in properties file at <url>" },
            { "doclet.usage.link-platform-properties.parameters", "<url>" },
            { "doclet.usage.link.description", "Create links to javadoc output at <url>" },
            { "doclet.usage.link.parameters", "<url>" },
            { "doclet.usage.linkoffline.description", "Link to docs at <url1> using package list at <url2>" },
            { "doclet.usage.linkoffline.parameters", "<url1> <url2>" },
            { "doclet.usage.linksource.description", "Generate source in HTML" },
            { "doclet.usage.main-stylesheet.description", "File to change style of the generated documentation" },
            { "doclet.usage.main-stylesheet.parameters", "<file>" },
            { "doclet.usage.no-frames.description", "Disable the use of frames in the generated output (default)" },
            { "doclet.usage.no-module-directories.description", "Do not group files for module documentation into \nmodule-specific directories" },
            { "doclet.usage.no-platform-links.description", "Do not generate links to the platform documentation" },
            { "doclet.usage.nocomment.description", "Suppress description and tags, generate only declarations" },
            { "doclet.usage.nodeprecated.description", "Do not include @deprecated information" },
            { "doclet.usage.nodeprecatedlist.description", "Do not generate deprecated list" },
            { "doclet.usage.nohelp.description", "Do not generate help link" },
            { "doclet.usage.noindex.description", "Do not generate index" },
            { "doclet.usage.nonavbar.description", "Do not generate navigation bar" },
            { "doclet.usage.nooverview.description", "Do not generate overview pages" },
            { "doclet.usage.noqualifier.description", "Exclude the list of qualifiers from the output" },
            { "doclet.usage.noqualifier.parameters", "<name1>:<name2>:..." },
            { "doclet.usage.nosince.description", "Do not include @since information" },
            { "doclet.usage.notimestamp.description", "Do not include hidden time stamp" },
            { "doclet.usage.notree.description", "Do not generate class hierarchy" },
            { "doclet.usage.override-methods.description", "Document overridden methods in the detail or summary sections" },
            { "doclet.usage.override-methods.parameters", "(detail|summary)" },
            { "doclet.usage.overview.description", "Read overview documentation from HTML file" },
            { "doclet.usage.overview.parameters", "<file>" },
            { "doclet.usage.serialwarn.description", "Generate warning about @serial tag" },
            { "doclet.usage.sourcetab.description", "Specify the number of spaces each tab takes up in the source" },
            { "doclet.usage.sourcetab.parameters", "<tab length>" },
            { "doclet.usage.splitindex.description", "Split index into one file per letter" },
            { "doclet.usage.tag.description", "Specify single argument custom tags" },
            { "doclet.usage.tag.parameters", "<name>:<locations>:<header>" },
            { "doclet.usage.taglet.description", "The fully qualified name of Taglet to register" },
            { "doclet.usage.tagletpath.description", "The path to Taglets" },
            { "doclet.usage.top.description", "Include top text for each page" },
            { "doclet.usage.top.parameters", "<html-code>" },
            { "doclet.usage.use.description", "Create class and package usage pages" },
            { "doclet.usage.version.description", "Include @version paragraphs" },
            { "doclet.usage.windowtitle.description", "Browser window title for the documentation" },
            { "doclet.usage.windowtitle.parameters", "<text>" },
            { "doclet.usage.xdoclint-extended.description", "Enable or disable specific checks for problems in javadoc\ncomments, where <group> is one of accessibility, html,\nmissing, reference, or syntax." },
            { "doclet.usage.xdoclint-extended.parameters", "(all|none|[-]<group>)" },
            { "doclet.usage.xdoclint-package.description", "Enable or disable checks in specific packages. <packages> is a\ncomma separated list of package specifiers. A package\nspecifier is either a qualified name of a package or a package\nname prefix followed by .*, which expands to all sub-packages\nof the given package. Prefix the package specifier with - to\ndisable checks for the specified packages." },
            { "doclet.usage.xdoclint-package.parameters", "([-]<packages>)" },
            { "doclet.usage.xdoclint.description", "Enable recommended checks for problems in javadoc comments" },
            { "doclet.usage.xdocrootparent.description", "Replaces all @docRoot followed by /.. in doc comments with\n<url>" },
            { "doclet.usage.xdocrootparent.parameters", "<url>" },
        };
    }
}
